@@ -244,6 +244,7 @@ method_changed (GtkComboBox *combo, gpointer user_data)
 	gboolean dhcp_enabled = FALSE;
 	gboolean routes_enabled = FALSE;
 	gboolean ip4_required_enabled = TRUE;
+	gboolean method_auto = FALSE;
 	GtkTreeIter iter;
 
 	if (gtk_combo_box_get_active_iter (priv->method, &iter)) {
@@ -255,6 +256,8 @@ method_changed (GtkComboBox *combo, gpointer user_data)
 	case IP4_METHOD_AUTO:
 		addr_enabled = FALSE;
 		dhcp_enabled = routes_enabled = TRUE;
+		dns_enabled = TRUE;
+		method_auto = TRUE;
 		break;
 	case IP4_METHOD_AUTO_ADDRESSES:
 		addr_enabled = FALSE;
@@ -290,11 +293,19 @@ method_changed (GtkComboBox *combo, gpointer user_data)
 	}
 
 	gtk_widget_set_sensitive (priv->dns_servers_label, dns_enabled);
+	if (method_auto)
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_servers_label), _("Additional _DNS servers:"));
+	else
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_servers_label), _("_DNS servers:"));
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->dns_servers), dns_enabled);
 	if (!dns_enabled)
 		gtk_entry_set_text (priv->dns_servers, "");
 
 	gtk_widget_set_sensitive (priv->dns_searches_label, dns_enabled);
+	if (method_auto)
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_searches_label), _("Additional s_earch domains:"));
+	else
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_searches_label), _("S_earch domains:"));
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->dns_searches), dns_enabled);
 	if (!dns_enabled)
 		gtk_entry_set_text (priv->dns_searches, "");
