@@ -247,6 +247,7 @@ method_changed (GtkComboBox *combo, gpointer user_data)
 	gboolean dns_enabled = FALSE;
 	gboolean routes_enabled = FALSE;
 	gboolean ip6_required_enabled = TRUE;
+	gboolean method_auto = FALSE;
 	GtkTreeIter iter;
 
 	if (gtk_combo_box_get_active_iter (priv->method, &iter)) {
@@ -258,6 +259,8 @@ method_changed (GtkComboBox *combo, gpointer user_data)
 	case IP6_METHOD_AUTO:
 		addr_enabled = FALSE;
 		routes_enabled = TRUE;
+		dns_enabled = TRUE;
+		method_auto = TRUE;
 		break;
 	case IP6_METHOD_AUTO_ADDRESSES:
 		addr_enabled = FALSE;
@@ -289,11 +292,19 @@ method_changed (GtkComboBox *combo, gpointer user_data)
 	}
 
 	gtk_widget_set_sensitive (priv->dns_servers_label, dns_enabled);
+	if (method_auto)
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_servers_label), _("Additional _DNS servers:"));
+	else
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_servers_label), _("_DNS servers:"));
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->dns_servers), dns_enabled);
 	if (!dns_enabled)
 		gtk_entry_set_text (priv->dns_servers, "");
 
 	gtk_widget_set_sensitive (priv->dns_searches_label, dns_enabled);
+	if (method_auto)
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_searches_label), _("Additional s_earch domains:"));
+	else
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->dns_searches_label), _("S_earch domains:"));
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->dns_searches), dns_enabled);
 	if (!dns_enabled)
 		gtk_entry_set_text (priv->dns_searches, "");
