@@ -26,7 +26,7 @@
 #include <ctype.h>
 
 #include <glib.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <gtk/gtk.h>
 
