@@ -24,6 +24,7 @@
 #include <string.h>
 #include <netinet/ether.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include <nm-setting-connection.h>
@@ -312,47 +313,16 @@ utils_escape_notify_message (const char *src)
 	return g_string_free (escaped, FALSE);
 }
 
-GnomeKeyringAttributeList *
-utils_create_keyring_add_attr_list (NMConnection *connection,
-                                    const char *connection_uuid,
-                                    const char *connection_id,
-                                    const char *setting_name,
-                                    const char *setting_key,
-                                    char **out_display_name)
+char *
+utils_create_mobile_connection_id (const char *provider, const char *plan_name)
 {
-	GnomeKeyringAttributeList *attrs = NULL;
-	NMSettingConnection *s_con;
+	g_return_val_if_fail (provider != NULL, NULL);
 
-	if (connection) {
-		s_con = nm_connection_get_setting_connection (connection);
-		g_return_val_if_fail (s_con != NULL, NULL);
-		connection_uuid = nm_setting_connection_get_uuid (s_con);
-		connection_id = nm_setting_connection_get_id (s_con);
-	}
+	if (plan_name)
+		return g_strdup_printf ("%s %s", provider, plan_name);
 
-	g_return_val_if_fail (connection_uuid != NULL, NULL);
-	g_return_val_if_fail (connection_id != NULL, NULL);
-	g_return_val_if_fail (setting_name != NULL, NULL);
-	g_return_val_if_fail (setting_key != NULL, NULL);
-
-	if (out_display_name) {
-		*out_display_name = g_strdup_printf ("Network secret for %s/%s/%s",
-		                                     connection_id,
-		                                     setting_name,
-		                                     setting_key);
-	}
-
-	attrs = gnome_keyring_attribute_list_new ();
-	gnome_keyring_attribute_list_append_string (attrs,
-	                                            KEYRING_UUID_TAG,
-	                                            connection_uuid);
-	gnome_keyring_attribute_list_append_string (attrs,
-	                                            KEYRING_SN_TAG,
-	                                            setting_name);
-	gnome_keyring_attribute_list_append_string (attrs,
-	                                            KEYRING_SK_TAG,
-	                                            setting_key);
-	return attrs;
+	/* The %s is a mobile provider name, eg "T-Mobile" */
+	return g_strdup_printf (_("%s connection"), provider);
 }
 
 void
